@@ -21,10 +21,10 @@
 package org.videolan.vlc.gui.video;
 
 import android.content.Context;
+import android.content.SharedPreferences;
 import android.databinding.BindingAdapter;
 import android.databinding.DataBindingUtil;
 import android.databinding.ViewDataBinding;
-import android.preference.PreferenceManager;
 import android.support.annotation.MainThread;
 import android.support.annotation.Nullable;
 import android.support.v7.widget.GridLayoutManager;
@@ -77,7 +77,8 @@ public class VideoListAdapter extends SortableAdapter<MediaWrapper, VideoListAda
     VideoListAdapter(IEventsHandler eventsHandler) {
         super();
         mEventsHandler = eventsHandler;
-        mIsSeenMediaMarkerVisible = PreferenceManager.getDefaultSharedPreferences(VLCApplication.getAppContext()).getBoolean("media_seen", true);
+        final SharedPreferences settings = VLCApplication.getSettings();
+        mIsSeenMediaMarkerVisible = settings == null || settings.getBoolean("media_seen", true);
     }
 
     @Override
@@ -387,14 +388,14 @@ public class VideoListAdapter extends SortableAdapter<MediaWrapper, VideoListAda
 
         @Override
         public boolean areItemsTheSame(int oldItemPosition, int newItemPosition) {
-            final MediaWrapper oldItem = getDataset().get(oldItemPosition);
+            final MediaWrapper oldItem = oldList.get(oldItemPosition);
             final MediaWrapper newItem = newList.get(newItemPosition);
             return oldItem == newItem || (oldItem.getType() == newItem.getType() && oldItem.equals(newItem));
         }
 
         @Override
         public boolean areContentsTheSame(int oldItemPosition, int newItemPosition) {
-            final MediaWrapper oldItem = getDataset().get(oldItemPosition);
+            final MediaWrapper oldItem = oldList.get(oldItemPosition);
             final MediaWrapper newItem = newList.get(newItemPosition);
             return oldItem == newItem || (oldItem.getTime() == newItem.getTime()
                     && TextUtils.equals(oldItem.getArtworkMrl(), newItem.getArtworkMrl())
@@ -404,7 +405,7 @@ public class VideoListAdapter extends SortableAdapter<MediaWrapper, VideoListAda
         @Nullable
         @Override
         public Object getChangePayload(int oldItemPosition, int newItemPosition) {
-            final MediaWrapper oldItem = getDataset().get(oldItemPosition);
+            final MediaWrapper oldItem = oldList.get(oldItemPosition);
             final MediaWrapper newItem = newList.get(newItemPosition);
             if (oldItem.getTime() != newItem.getTime())
                 return UPDATE_TIME;
